# access keys
PAYDUNYA_ACCESS_TOKENS = {
    'PAYDUNYA-MASTER-KEY': "5b9f531a-fbb8-487a-8045-3b4c7ac5acee",
    'PAYDUNYA-PRIVATE-KEY': "test_private_oGslgmzSNL3RSkjlsnPOsZZg9IA",
    'PAYDUNYA-TOKEN': "ff1d576409b2587cc1c2"
}
